==> meld-library-http-undertow-0.1.2-sources.jar: ch/raffael/meldioc/library/http/server/undertow/routing/RoutingDefinitions.java <==
/*
 *  Copyright (c) 2019 Raffael Herzog
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to
 *  deal in the Software without restriction, including without limitation the
 *  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 *  sell copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 *  IN THE SOFTWARE.
 */

package ch.raffael.meldioc.library.http.server.undertow.routing;

import io.undertow.server.HttpHandler;
import io.undertow.server.HttpServerExchange;

import java.util.function.Function;

/**
 * Utilities for dealing with {@link RoutingDefinition} instances.
 */
public class RoutingDefinitions {

  @SuppressWarnings("ObjectEquality")
  public static <C> HttpHandler buildHandlerTree(RoutingDefinition<? super C> routingDefinition,
                                                 Function<? super HttpServerExchange, ? extends C> contextFactory) {
    if (routingDefinition.currentFrame != routingDefinition.rootFrame) {
      throw new IllegalStateException("Routing definition is not at top frame");
    }
    return routingDefinition.currentFrame.handler(contextFactory);
  }

}

==> meld-library-http-undertow-0.2.0-sources.jar: ch/raffael/meldioc/library/http/server/undertow/routing/RoutingDefinitions.java <==
/*
 *  Copyright (c) 2022 Raffael Herzog
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to
 *  deal in the Software without restriction, including without limitation the
 *  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 *  sell copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 *  IN THE SOFTWARE.
 */

package ch.raffael.meldioc.library.http.server.undertow.routing;

import io.undertow.server.HttpHandler;

/**
 * Utilities for dealing with {@link RoutingDefinition} instances.
 */
public class RoutingDefinitions {

  @SuppressWarnings("ObjectEquality")
  public static HttpHandler materialize(RoutingDefinition routingDefinition) {
    if (routingDefinition.currentFrame != routingDefinition.rootFrame) {
      throw new IllegalStateException("Routing definition is not at top frame");
    }
    return routingDefinition.currentFrame.materialize();
  }
}
